.. module:: MiscUtils

.. _miscutils:

MiscUtils
=========

The MiscUtils package provides support classes and functions to Webware that aren't necessarily web-related and that don't fit into one of the other frameworks. There is plenty of useful reusable code here.

See the :ref:`reference documentation <ref-miscutils>` for an overview of the available functions.
